import * as i0 from '@angular/core';
import { Directive, Input, Component } from '@angular/core';
import * as qrCodeService from '@mintplayer/qr-code';

class QrCodeDirective {
    constructor(viewContainerRef) {
        this.viewContainerRef = viewContainerRef;
        //#region Version
        this.version = null;
        this.darkColor = '#000000FF';
        this.lightColor = '#FFFFFFFF';
        this.errorCorrectionLevel = QrCodeDirective.DEFAULT_ERROR_CORRECTION_LEVEL;
        this.margin = 16;
    }
    static { this.VALID_COLOR_REGEX = /^#(?:[0-9a-fA-F]{3,4}){1,2}$/; }
    static { this.DEFAULT_ERROR_CORRECTION_LEVEL = 'M'; }
    static { this.DEFAULT_CENTER_IMAGE_SIZE = 40; }
    set qrCodeVersion(value) {
        if (value && (value > 40)) {
            this.version = 40;
        }
        else if (value && (value < 1)) {
            this.version = 1;
        }
        else {
            this.version = null;
        }
    }
    async ngOnChanges() {
        if (!this.value) {
            return;
        }
        const canvas = this.viewContainerRef.element.nativeElement;
        if (!canvas) {
            // native element not available on server side rendering
            return;
        }
        const context = canvas.getContext('2d');
        if (context) {
            context.clearRect(0, 0, context.canvas.width, context.canvas.height);
        }
        const errorCorrectionLevel = this.errorCorrectionLevel ?? QrCodeDirective.DEFAULT_ERROR_CORRECTION_LEVEL;
        const dark = !this.darkColor
            ? undefined
            : QrCodeDirective.VALID_COLOR_REGEX.test(this.darkColor)
                ? this.darkColor
                : undefined;
        const light = !this.lightColor
            ? undefined
            : QrCodeDirective.VALID_COLOR_REGEX.test(this.lightColor)
                ? this.lightColor
                : undefined;
        await qrCodeService
            .toCanvas(canvas, this.value, {
            version: this.version ?? undefined,
            errorCorrectionLevel,
            width: this.width,
            margin: this.margin,
            color: {
                dark,
                light,
            },
        });
        const centerImageSrc = this.centerImageSrc;
        const centerImageWidth = this.getIntOrDefault(this.centerImageWidth, QrCodeDirective.DEFAULT_CENTER_IMAGE_SIZE);
        const centerImageHeight = this.getIntOrDefault(this.centerImageHeight, QrCodeDirective.DEFAULT_CENTER_IMAGE_SIZE);
        if (centerImageSrc && context) {
            if (!this.centerImage) {
                this.centerImage = new Image(centerImageWidth, centerImageHeight);
            }
            if (centerImageSrc !== this.centerImage?.src) {
                this.centerImage.src = centerImageSrc;
            }
            if (centerImageWidth !== this.centerImage.width) {
                this.centerImage.width = centerImageWidth;
            }
            if (centerImageHeight !== this.centerImage.height) {
                this.centerImage.height = centerImageHeight;
            }
            const centerImage = this.centerImage;
            centerImage.onload = () => {
                context.drawImage(centerImage, canvas.width / 2 - centerImageWidth / 2, canvas.height / 2 - centerImageHeight / 2, centerImageWidth, centerImageHeight);
            };
        }
    }
    getIntOrDefault(value, defaultValue) {
        if (value === undefined || value === '') {
            return defaultValue;
        }
        else if (typeof value === 'string') {
            return parseInt(value, 10);
        }
        else {
            return value;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: QrCodeDirective, deps: [{ token: i0.ViewContainerRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.1", type: QrCodeDirective, isStandalone: true, selector: "canvas[qrCode]", inputs: { value: ["qrCode", "value"], qrCodeVersion: "qrCodeVersion", width: "width", height: "height", darkColor: "darkColor", lightColor: "lightColor", errorCorrectionLevel: ["qrCodeErrorCorrectionLevel", "errorCorrectionLevel"], centerImageSrc: ["qrCodeCenterImageSrc", "centerImageSrc"], centerImageWidth: ["qrCodeCenterImageWidth", "centerImageWidth"], centerImageHeight: ["qrCodeCenterImageHeight", "centerImageHeight"], margin: ["qrCodeMargin", "margin"] }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: QrCodeDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'canvas[qrCode]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ViewContainerRef }], propDecorators: { value: [{
                type: Input,
                args: ['qrCode']
            }], qrCodeVersion: [{
                type: Input
            }], width: [{
                type: Input
            }], height: [{
                type: Input
            }], darkColor: [{
                type: Input
            }], lightColor: [{
                type: Input
            }], errorCorrectionLevel: [{
                type: Input,
                args: ['qrCodeErrorCorrectionLevel']
            }], centerImageSrc: [{
                type: Input,
                args: ['qrCodeCenterImageSrc']
            }], centerImageWidth: [{
                type: Input,
                args: ['qrCodeCenterImageWidth']
            }], centerImageHeight: [{
                type: Input,
                args: ['qrCodeCenterImageHeight']
            }], margin: [{
                type: Input,
                args: ['qrCodeMargin']
            }] } });

class QrCodeComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: QrCodeComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.1", type: QrCodeComponent, isStandalone: true, selector: "qr-code", inputs: { value: "value", size: "size", darkColor: "darkColor", lightColor: "lightColor", errorCorrectionLevel: "errorCorrectionLevel", centerImageSrc: "centerImageSrc", centerImageSize: "centerImageSize", margin: "margin" }, ngImport: i0, template: "@if (value) {\n    <canvas\n        [qrCode]=\"value\"\n        [qrCodeErrorCorrectionLevel]=\"errorCorrectionLevel\"\n        [qrCodeCenterImageSrc]=\"centerImageSrc\"\n        [qrCodeCenterImageWidth]=\"centerImageSize\"\n        [qrCodeCenterImageHeight]=\"centerImageSize\"\n        [qrCodeMargin]=\"margin\"\n        [width]=\"size\"\n        [height]=\"size\"\n        [darkColor]=\"darkColor\"\n        [lightColor]=\"lightColor\">\n    </canvas>\n}", styles: [""], dependencies: [{ kind: "directive", type: QrCodeDirective, selector: "canvas[qrCode]", inputs: ["qrCode", "qrCodeVersion", "width", "height", "darkColor", "lightColor", "qrCodeErrorCorrectionLevel", "qrCodeCenterImageSrc", "qrCodeCenterImageWidth", "qrCodeCenterImageHeight", "qrCodeMargin"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: QrCodeComponent, decorators: [{
            type: Component,
            args: [{ selector: 'qr-code', standalone: true, imports: [QrCodeDirective], template: "@if (value) {\n    <canvas\n        [qrCode]=\"value\"\n        [qrCodeErrorCorrectionLevel]=\"errorCorrectionLevel\"\n        [qrCodeCenterImageSrc]=\"centerImageSrc\"\n        [qrCodeCenterImageWidth]=\"centerImageSize\"\n        [qrCodeCenterImageHeight]=\"centerImageSize\"\n        [qrCodeMargin]=\"margin\"\n        [width]=\"size\"\n        [height]=\"size\"\n        [darkColor]=\"darkColor\"\n        [lightColor]=\"lightColor\">\n    </canvas>\n}" }]
        }], propDecorators: { value: [{
                type: Input
            }], size: [{
                type: Input
            }], darkColor: [{
                type: Input
            }], lightColor: [{
                type: Input
            }], errorCorrectionLevel: [{
                type: Input
            }], centerImageSrc: [{
                type: Input
            }], centerImageSize: [{
                type: Input
            }], margin: [{
                type: Input
            }] } });

/**
 * Generated bundle index. Do not edit.
 */

export { QrCodeComponent, QrCodeDirective };
//# sourceMappingURL=mintplayer-ng-qr-code.mjs.map
